@@ -8,8 +8,8 @@ import platform
 import qdarkstyle
 import requests
 import math
-import base64
 import imgviz
+from multiprocessing import Process
 
 from qtpy import QtCore
 from qtpy.QtCore import Qt
